@@ -4,12 +4,12 @@ use strict;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common 2.087 qw(:Status);
+use IO::Compress::Base::Common 2.088 qw(:Status);
 
-use Compress::Raw::Lzma 2.087 ;
+use Compress::Raw::Lzma 2.088 ;
 
 our ($VERSION, @ISA);
-$VERSION = '2.087';
+$VERSION = '2.088';
 
 #@ISA = qw( Compress::Raw::UnLzma );
 
@@ -60,6 +60,7 @@ sub mkUncompZipObject
                   'UnCompSize'    => 0,
                   'Error'         => '',
                   'ConsumesInput' => 1,
+                  'ResetData'     => $properties,       
                   #'CompressedLen' => $CompressedLength || 0,
                   #'UncompressedLen' => $UncompressedLength || 0,
                  }  ;     
@@ -95,7 +96,8 @@ sub reset
 {
     my $self = shift ;
 
-    my ($inf, $status) = Compress::Raw::Lzma::AloneDecoder->new(AppendOutput => 1,
+    my ($inf, $status) = Compress::Raw::Lzma::RawDecoder->new(AppendOutput => 1,
+                                              Properties => $self->{'ResetData'},
                                               ConsumeInput => 1, 
                                               LimitOutput => 1);
     $self->{ErrorNo} = ($status == LZMA_OK) ? 0 : $status ;
